unit DemoApp;

{ -----------------------------------------------------------------------------}
{ Unit: DemoApp                                                                }
{ Purpose: Demo to show you how to use the Converters-unit                     }
{ Required: the TRichEdit98. See enclosed zip. This demo could also use        }
{           an imported RICHTX32.OCX, but you'll have to modify the form for   }
{           this to work.                                                      }
{ Authors: Fred Jansma, Paul te Bokkel                                         }
{          Incontrol Business Engineers                                        }
{ -----------------------------------------------------------------------------}

{ Copyright (c) 1998 Paul te Bokkel & Fred Jansma, Incontrol Business Engineers}

{ This program is free software; you can redistribute it and/or                }
{ modify it under the terms of the GNU General Public License                  }
{ as published by the Free Software Foundation; either version 2               }
{ of the License, or (at your option) any later version.                       }

{ This program is distributed in the hope that it will be useful,              }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of               }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                }
{ GNU General Public License for more details.                                 }

{ You should have received a copy of the GNU General Public License            }
{ along with this program; if not, write to the Free Software                  }
{ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.  }

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Converters, AxCtrls, OleCtrls, Menus, filectrl, ComCtrls,
  StdCtrls, RichEdit2;

type
  TformMain = class(TForm)
    mmMain: TMainMenu;
    mmFile: TMenuItem;
    mmOpen: TMenuItem;
    mmSaveAs: TMenuItem;
    N1: TMenuItem;
    mmClose: TMenuItem;
    OpenDialog: TOpenDialog;
    SaveDialog: TSaveDialog;
    sbStatus: TStatusBar;
    reApp: TRichEdit98;
    procedure mmOpenClick(Sender: TObject);
    procedure mmSaveAsClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  formMain: TformMain;

implementation

{$R *.DFM}

procedure TformMain.mmOpenClick(Sender: TObject);
var
  StrLst: TStringList;
  SelectedFormat: String;

begin
  StrLst := TStringList.Create;

  try
    // Search for all available filters and add them to the filter of your dialog.
    OpenDialog.Filter := BuildFilterList(True);

    // If we have selected a file, import it.
    if OpenDialog.Execute then
      begin
        BuildConverterList(True, StrLst);
        SelectedFormat := StrLst.Strings[OpenDialog.FilterIndex - 1]; // - 1 while FilterIndex starts at 1.

        sbStatus.SimpleText := 'Loading file...';
        if Pos('Rich Text', SelectedFormat) > 0 then
          begin
            // Native format. Load directly, without any converter.
            reApp.Lines.LoadFromFile(OpenDialog.FileName);
            sbStatus.SimpleText := 'Done';
            Exit;
          end;

        if ImportAsRTF(OpenDialog.FileName, SelectedFormat, reApp) then
          sbStatus.SimpleText := 'Succesfully imported: ' + OpenDialog.FileName;
      end;
  finally
    StrLst.Free;
  end;
end;

procedure TformMain.mmSaveAsClick(Sender: TObject);
var
  StrLst: TStringList;
  SelectedFormat: String;
begin
  StrLst := TStringList.Create;

  try
    // Search for all available filters and add them to the filter of your dialog.
    SaveDialog.Filter := BuildFilterList(False);

    // If we have selected a filename, export to it.
    if SaveDialog.Execute then
      begin
        BuildConverterList(False, StrLst);
        SelectedFormat := StrLst.Strings[SaveDialog.FilterIndex - 1]; // - 1 while FilterIndex starts at 1.

        sbStatus.SimpleText := 'Exporting file...';

        if Pos('Rich Text', SelectedFormat) > 0 then
          begin
            // Native format. Save directly, without any converter.
            reApp.Lines.SaveToFile(SaveDialog.FileName);
            sbStatus.SimpleText := 'Done';
            Exit;
          end;

        if ExportRTF(SaveDialog.FileName, SelectedFormat, reApp) then
          sbStatus.SimpleText := 'Succesfully exported: ' + SaveDialog.FileName;
      end;
  finally
    StrLst.Free;
  end;
end;

end.
